Learn R Programming

sigora (version 3.2.0)

getURL: Highlight the relevant genes for a specific pathway in its pathway diagram

Description

This function highlights the genes involved in the present GPS for a pathway of interest in its diagram. Please note that this functionality is only implemented for results of Reactome or KEGG based analyses.

Usage

getURL(yy, i)

Value

The URL of the pathway diagram, where the relevant genes from your original query list are highlighted.

Arguments

yy

A sigora analysis result object (created by sigora).

i

The rank position of the pathway of interest in summary_results.

See Also

sigora

Examples

Run this code

data("kegH")
set.seed(seed=12345)
a1<-genesFromRandomPathways(kegH,3,50)
## originally selected pathways:\cr
a1[["selectedPathways"]]
## what are the genes
a1[["genes"]]
## sigora's results with this input:\cr
sigoraRes <- sigora(GPSrepo =kegH, queryList = a1[["genes"]],level = 2)
## Diagram for the most significant result,
## genes from our list are highlighted in red:
getURL(sigoraRes,1)

Run the code above in your browser using DataLab