PID-NCI human pathway repository, as a data frame with three columns
corresponding to : pathwayId , pathwayName, gene. This is an example of the
expected format for the input data to makeGPS.
Arguments
Details
This dataset is provided to illustrate how to create your own GPS
repositories.nciTable is a dataframe with threecolumns corresponding
to pathwayId, pathwayName and gene. Each row describes the association
between an individual gene and a PID-NCI pathway. As you see in the
examples, section, one can convert this dataframe to a GPS
repository using makeGPS, and save the results for future reuse.
Using the thus created GPS repository one can preform Signature
Overrepresentation Analysis on lists of genes of interest.